function fig2()
warning off MATLAB:polyfit:RepeatedPointsOrRescale
load Database_20120728

close all
clc

MHL = 16;
HL = 28;

uavg = [];
S = [];
conf_interval = [];
kurts = [];
P = zeros(size(GetHitResults(DB,1,1)));
Q = P;
UserValues = [];
mu = [];

% computed from octave
% tinv((1-p)/2,34)
% where p is percentage confidence (i.e. 95%)
% and 34 is n-1 = number of observers minus 1
% 95% confidence interval
%t = 2.0322;
% 99% confidence interval
%t = 2.7284;
% ITU standard says to use 1.96
t = 1.96;

% Get overall stats, average, std, and kurtosis
% Store the user values too so that we can screen them
for m = 0:MHL-1
    for h = 0:HL-1
        r = GetHitResults(DB, m, h);
        UserValues = [UserValues; r];
        mu = [mu mean(r)];
        S = [S std(r)];
        %conf_interval = [conf_interval t*std(r)/sqrt(length(r))];
        % ITU standard defines the kurtosis as
        % m4 /( (m2)^2 )
        kurts = [kurts momentx(r,4)/(momentx(r,2)^2)];     
    end
end

% Process individual values for screening
for i=1:length(P)
    for k = 1:length(kurts)
        if (kurts(k) <= 4)&&(kurts(k) >= 2)
            % This is a normal distribution
            if UserValues(k, i) >= (mu(k)+2*S(k))
                P(i) = P(i) + 1;
            end
            if UserValues(k, i) <= (mu(k)-2*S(k))
                Q(i) = Q(i) + 1;
            end
        else
            % This data doesn't seem to be normal
            % so we need to use different thresholds
            if UserValues(k, i) >= (mu(k)+sqrt(20)*S(k))
                P(i) = P(i) + 1;
            end
            if UserValues(k, i) <= (mu(k)-sqrt(20)*S(k))
                Q(i) = Q(i) + 1;
            end
        end
    end
end

REJECTS = ((P+Q)/length(mu) > 0.05) & (abs( (P-Q)./(P+Q) ) < 0.3);
valid_IDs = GetCompleted(DB);
fprintf('The reject is UserId = %d.\n', valid_IDs(find(REJECTS > 0)) );

% Recompute values after screening
% Get overall stats, average, std, and kurtosis
% Store the user values too so that we can screen them
mu = [];
S = [];
conf_interval = [];
for m = 0:MHL-1
    for h = 0:HL-1
        r = GetHitResults(DB, m, h);
        % Screen
        r = r( ~REJECTS );
        
        mu = [mu mean(r)];
        S = [S std(r)];
        conf_interval = [conf_interval t*std(r)/sqrt(length(r))];
    end
end

figure;
[a b] = sort(mu, 'descend');
x = 1:length(mu);
p = polyfit(x, mu(b)+conf_interval(b),11);
p2 = polyfit(x, mu(b)-conf_interval(b),11);
plot(x, mu(b), x, polyval(p,x), 'r--', x, polyval(p2,x),'r--', ...
    'LineWidth', 2, 'MarkerSize',2)
ylim([1 5])
grid

gl = legend('MOS', 'Confidence Interval');
set(gl, 'FontSize', 16, 'FontName', 'Times')
xlabel('k', 'FontSize', 16, 'FontName', 'Times')
ylabel('Sorted MOS','FontSize', 16, 'FontName', 'Times');
xlim([1 length(mu)])
set(gca, 'Ytick',[1 1.5 2 2.5 3 3.5 4 4.5 5], 'Xtick', [])
%savetopdf('../fig2a');

figure
[h i] = hist(mu,10);
bar(i, h/sum(h), 'FaceColor', [0.5, 0.5, 0.5]);
xlabel('MOS','FontSize', 16, 'FontName', 'Times')
ylabel('Frequency','FontSize', 16, 'FontName', 'Times')
%savetopdf('../fig2b');
end

function savetopdf(rootname)
    %imshow(data(index).im);
    print('-depsc', '-r300', [rootname, '.eps']);
    system(['epstopdf ', rootname, '.eps']);
end