% %% Below is the settings I used within TestGentleBoost
% % Percentage of data points to train from
% TRAIN_PERC = 0.5;
% Ncv = 1000;
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% AdaBoost Options
options.method       = 7;
options.holding.rho  = 0.7;
options.holding.K    = 1000;
options.weaklearner  = 0;
options.epsi         = 0.1;
options.lambda       = 1e-2;
options.max_ite      = 1000;
options.T            = 80;
options.Ncv          = 1000; % Number of cross-validations
options.train_perc   = 0.5;
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
addpath Tools\gentleboost\

FD = load('01262012_fpool.mat');
F_ISCAS = FD.Fpool;

% Use GetFeaturePoolJournalSimple
FD = load('fpool_journal_diff.mat');
F_Diff = FD.fpool_jsimple;

[new_mos conf_interval] = GetScreenedMOS();
conf_interval = mean(conf_interval);
new_mos = new_mos(:); %vectorize

F_ISCAS(:,1) = new_mos(:);
F_Diff(:,1) = new_mos(:);

% I need to remove the last 4 of F_Diff to match
% the paper.
% This is because features 12-15 were bin differences
% which I didn't include in the paper
F_Diff = F_Diff(:, 1:end-4);

fprintf('Confidence Interval is %0.3f\n.', conf_interval);
fprintf('Setting middle range to be [%0.3f %0.3f]\n', 3-conf_interval, 3+conf_interval);

fprintf('ISCAS: ');
[mos_bad mos_good] = HowManyMOSBetween(F_ISCAS, 3-conf_interval, 3+conf_interval);
resultsCEM_ISCAS = TestGentleBoost(F_ISCAS(mos_good,:), options);

fprintf('Diff: ');
F_Diff_n = F_Diff;
mu = mean(F_Diff_n(:,2:end));
sigma = std(F_Diff_n(:,2:end));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Normalize to zero mean, unit variance
F_Diff_n(:,2:end) = (F_Diff(:,2:end) - repmat(mu,448,1))./repmat(sigma,448,1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[mos_bad mos_good] = HowManyMOSBetween(F_Diff_n, 3-conf_interval, 3+conf_interval);
resultsCEM_Diff = TestGentleBoost(F_Diff_n(mos_good,:), options);

fprintf('HVS Based: ');
resultsCEM_Diff_HVS = TestGentleBoost(F_Diff_n(mos_good,1:8), options);

fprintf('CEF Based: ');
resultsCEM_Diff_CEF = TestGentleBoost(F_Diff_n(mos_good, [1 9:12]), options);


%% Figures
close all
fig7a( resultsCEM_ISCAS, resultsCEM_Diff );
fig7b( resultsCEM_ISCAS, resultsCEM_Diff_HVS, resultsCEM_Diff_CEF, resultsCEM_Diff );
%% Text results
clc
fprintf('Test Errors:\n');
fprintf('ISCAS Test error (mean, std) : %0.3f, %0.3f\n', mean(resultsCEM_ISCAS.error_test), ...
                                                         std(resultsCEM_ISCAS.error_test));
fprintf('Diff Test Error (mean, std) : %0.3f, %0.3f\n', mean(resultsCEM_Diff.error_test), ...
                                                        std(resultsCEM_Diff.error_test));
fprintf('Diff (HVS Only) Test Error (mean, std) : %0.3f, %0.3f\n', mean(resultsCEM_Diff_HVS.error_test), ...
                                                        std(resultsCEM_Diff_HVS.error_test));
fprintf('Diff (CEF Only) Test Error (mean, std) : %0.3f, %0.3f\n', mean(resultsCEM_Diff_CEF.error_test), ...
                                                        std(resultsCEM_Diff_CEF.error_test));
fprintf('\n');
fprintf('Diff Spearman : %0.3f\n', mean(resultsCEM_Diff.spear));
fprintf('Diff Pearson : %0.3f\n', mean(resultsCEM_Diff.pear));
fprintf('HVS  Spearman : %0.3f\n', mean(resultsCEM_Diff_HVS.spear));
fprintf('HVS  Pearson : %0.3f\n', mean(resultsCEM_Diff_HVS.pear));
fprintf('CEF  Spearman : %0.3f\n', mean(resultsCEM_Diff_CEF.spear));
fprintf('CEF  Pearson : %0.3f\n', mean(resultsCEM_Diff_CEF.pear));
fprintf('ISCASS Spearman : %0.3f\n', mean(resultsCEM_ISCAS.spear));
fprintf('ISCASS Pearson : %0.3f\n', mean(resultsCEM_ISCAS.pear));

fprintf('AUC:\n');
fprintf('ISCAS AUC : %0.3f\n', auroc(resultsCEM_ISCAS.tptest_mean', resultsCEM_ISCAS.fptest_mean'))
fprintf('Diff AUC  : %0.3f\n', auroc(resultsCEM_Diff.tptest_mean', resultsCEM_Diff.fptest_mean'))
fprintf('Diff (HVS Only) AUC  : %0.3f\n', auroc(resultsCEM_Diff_HVS.tptest_mean', resultsCEM_Diff_HVS.fptest_mean'))
fprintf('Diff (CEF Only) AUC  : %0.3f\n', auroc(resultsCEM_Diff_CEF.tptest_mean', resultsCEM_Diff_CEF.fptest_mean'))