function out = TestGentleBoost(feature_pool, options)
% test with gentle adaboost method
% Obtain indexing information to image files, etc.
% Gives us structre: DB_ISCAS2012
load Database_ISCAS2012

if ~exist('options', 'var' ) 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % OPTIONS
    options.method       = 7;
    options.holding.rho  = 0.7;
    options.holding.K    = 1000;

    options.weaklearner  = 0;
    options.epsi         = 0.1;
    options.lambda       = 1e-2;
    options.max_ite      = 1000;
    options.T            = 100;
    options.Ncv          = 1000;
    options.train_perc   = 0.5;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end

TRAIN_PERC = options.train_perc;
Ncv = options.Ncv;
% ISCAS2012 paper;
% load 10102011_fpool;
% feature_pool = Fpool;
% current scheme
% load  02162012_fpool10.mat;
% feature_pool = fpool10;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Train using adaboost

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% binary class
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

allfeatures = zeros(options.T*Ncv - options.T, 1);
allf_idx = 1;
textprogressbar('Gentle Boosting: ');
for i = 1:Ncv
    % Obtain a: training indexes and b: validation indexes
    [a b] = GetTrainValIdxs(feature_pool, TRAIN_PERC);
    % Training data
    Xtrain =  feature_pool(a,2:end); % Features : M1-M13
    Xtrain = Xtrain';
    ytrain = 2*(feature_pool(a,1)>3) - 1;
    % Testing data
    Xtest =  feature_pool(b,2:end); % Features : M1-M13
    Xtest = Xtest';
    ytest = 2*(feature_pool(b,1)>3) - 1;

    labels               = unique(ytrain);
    positive             = labels(end);
    Ntrain = length(ytrain);
    model_gentle            = gentleboost_model(Xtrain , ytrain , options);

    [ytrain_est , fxtrain]   = gentleboost_predict(Xtrain , model_gentle);
    error_train(i)              = sum(ytrain_est(:)~=ytrain(:))/Ntrain;

    ytrain(ytrain(:) ~=positive(:))	= -1;
    ytrain(ytrain(:) ==positive(:))	 = 1;
    ind_positive         = find(labels==positive);
    [tptrain(i , :) , fptrain(i , :)]	= basicroc(ytrain , fxtrain(1 , :));

    Ntest = length(ytest);
    [ytest_est , fxtest, aw]	 = gentleboost_predict(Xtest , model_gentle);
    error_test(i)               = sum(ytest_est(:)~=ytest(:))/Ntest;
    
    if 0
        % Measure with confidence values and MOS values
    [spear_test(i) spearp_test(i)] = corr(fxtest(:), feature_pool(b,1), 'type', 'Spearman');
    [ken_test(i) kenp_test(i)] = corr(fxtest(:), feature_pool(b,1), 'type', 'Kendall');
    [pear_test(i) pearp_test(i)] = corr(fxtest(:), feature_pool(b,1), 'type', 'Pearson');
    else
        % Measure with binary values
    [spear_test(i) spearp_test(i)] = corr(ytest_est(:), ytest(:), 'type', 'Spearman');
    [ken_test(i) kenp_test(i)] = corr(ytest_est(:), ytest(:), 'type', 'Kendall');
    [pear_test(i) pearp_test(i)] = corr(ytest_est(:), ytest(:), 'type', 'Pearson');
    end
    
    ytest(ytest ~=positive)        = -1;
    ytest(ytest ==positive)        = 1;
    [tptest(i , :) , fptest(i , :)]     = basicroc(ytest , fxtest(1 , :));
    
    allfeatures(allf_idx:allf_idx+options.T-1) = model_gentle.featureIdx(:);
    allf_idx = (i-1)*options.T + 1;

    %fprintf('%d/%d\n' , i , options.holding.K)
    drawnow
    textprogressbar(i*100/Ncv);
end
textprogressbar(', done.')
fprintf('Error Train/Test %2.4f/%2.4f\n' , mean(error_train,2) , mean(error_test,2))

fptrain_mean                          = mean(fptrain);
tptrain_mean                          = mean(tptrain);
auc_train                             = auroc(tptrain_mean', fptrain_mean');

fptest_mean                           = mean(fptest);
tptest_mean                           = mean(tptest);
auc_test                              = auroc(tptest_mean', fptest_mean');

out.fptrain_mean = fptrain_mean;
out.tptrain_mean = tptrain_mean;
out.fptest_mean = fptest_mean;
out.tptest_mean = tptest_mean;
out.error_train = error_train;
out.error_test = error_test;
out.allfeatures = allfeatures;
out.spear = spear_test;
out.ken = ken_test;
out.spear_p = spearp_test;
out.ken_p = kenp_test;
out.pear = pear_test;
out.pear_p = pearp_test;

end
