function [t,A] = drk_prior_mdcp(xhat,K,plot,A)
%drk = drk_prior_noA(im)
% Process a dark channel prior image
% and generate a raw transmission
% image based on the estimated airlight vector.
% "Single Image Haze Removal Using Dark Channel Prior"
% He, Sun, Tang: Microsoft Asia
% Inputs:
%       im      = Hazy image (grayscale or RGB)
%       K       = Size of the kernel
%       plot    = true - shows results of airlight estimate and
%                 transmission.
%       A       = Only use this if you already have an airlight vector.

im = im2double(xhat);

% Sometimes lowering this to 0.8 or raising to 0.98 may improve results.
%w = 0.98;
w = 0.90;
% How many pixels to consider when estimating airlight
perc = 0.01;

R = im(:,:,1);
if( size(im,3) > 1 )
    G = im(:,:,2);
    B = im(:,:,3);
else
    G = im;
    B = im;
end

drk1 = min( R,   G );
drk2 = min( B, drk1);

v = imerode(drk2, ones(K));

% Estimate airlight %%%%%%%%%%%%%%%%%%%%
Amask = 0*R;
v = v(:);
[Y, I] = sort(v,'descend');
M = floor(perc*size(v,1));
% Choose the top small percentage of pixels
br_ix = I(1:M);
r = R(:); g = G(:); b = B(:);
r( r >=1 ) = 0;
g( g >=1 ) = 0;
b( b >=1 ) = 0;
r = r(br_ix);g = g(br_ix);b = b(br_ix);

% top 1/8
% r = im(1:end/8,:,1);
% g = im(1:end/8,:,2);
% b = im(1:end/8,:,3);
% r = r(:); g = g(:); b = b(:);

if nargin == 4
else
    A(1) = mean(r);
    A(2) = mean(g);
    A(3) = mean(b);
end

drk1 = min( R/A(1),   G/A(2) );
drk2 = min( B/A(3), drk1);

drk = medfilt2(drk2,[K K],'symmetric');

t = 1 - w*drk;

BLOCK = 64;
if nargin > 2
    imagesc(t);axis image off;colormap gray;title('t');
    R(br_ix) = 1;G(br_ix) = 0;B(br_ix) = 0;
    im_sel = zeros(size(R,1),size(R,2),3);
    im_sel(:,:,1) = R;im_sel(:,:,2) = G;im_sel(:,:,3) = B;
    im_sel(end-BLOCK:end,end-BLOCK:end,1) = A(1);
    im_sel(end-BLOCK:end,end-BLOCK:end,2) = A(2);
    im_sel(end-BLOCK:end,end-BLOCK:end,3) = A(3);
    % Red box
    im_sel(end-BLOCK:end,end-BLOCK-1:end-BLOCK,1) = 255;im_sel(end-BLOCK:end,end-BLOCK-1:end-BLOCK,2) = 0;im_sel(end-BLOCK:end,end-BLOCK-1:end-BLOCK,3) = 0;
    im_sel(end-BLOCK-1:end-BLOCK,end-BLOCK:end,1) = 255;im_sel(end-BLOCK-1:end-BLOCK,end-BLOCK:end,2) = 0;im_sel(end-BLOCK-1:end-BLOCK,end-BLOCK:end,3) = 0;
    figure;imagesc(uint8(255*im_sel));axis image off;title('Airlight Mask')
end

end